@@ -138,10 +138,10 @@ int is_shlib(char *dir, char *name)
 	    warn("can't open %s (%s), skipping", buff, strerror(errno));
 	else
 	{
-	    /* now make sure it's ZMAGIC with a non-zero address */
+	    /* now make sure it's ZMAGIC or QMAGIC with a non-zero address */
 	    if (fread(&exec, sizeof exec, 1, file) < 1)
 		warn("can't read header from %s, skipping", buff);
-	    else if (N_MAGIC(exec) != ZMAGIC)
+	    else if (N_MAGIC(exec) != ZMAGIC && N_MAGIC(exec) != QMAGIC)
 		warn("%s is not a ZMAGIC file, skipping", buff);
 	    else if (!exec.a_entry)
 		warn("%s has a zero load address, skipping", buff);
@@ -335,7 +335,7 @@ int main(int argc, char **argv)
     int printcache = 0;
     char *cp, *dir;
     char *extpath;
-    char defpath[] = DEFAULT_PATH;
+    static char defpath[] = DEFAULT_PATH;
 
     prog = argv[0];
     opterr = 0;
